@@ -11,7 +11,8 @@ xml_serde_enum! {
 pub type StBorderId = u32;
 
 xml_serde_enum! {
-    #[derive(Debug, PartialEq, Eq, Hash, Clone, serde::Serialize)]
+    #[derive(Debug, PartialEq, Eq, Hash, Clone, serde::Serialize, TS)]
+    #[ts(export, export_to = "../../../src/bindings/st_border_style.ts")]
     StBorderStyle {
         None => "none",
         Thin => "thin",
@@ -350,7 +351,8 @@ xml_serde_enum! {
 pub type StFontId = u32;
 
 xml_serde_enum! {
-    #[derive(Debug, PartialEq, Eq, Hash, Clone, serde::Serialize)]
+    #[derive(Debug, PartialEq, Eq, Hash, Clone, serde::Serialize, TS)]
+    #[ts(export, export_to = "../../../src/bindings/st_font_scheme.ts")]
     StFontScheme {
         None => "none",
         Major => "major",
@@ -384,7 +386,8 @@ xml_serde_enum! {
 
 xml_serde_enum! {
     /// 18.18.37
-    #[derive(Debug, PartialEq, Eq, Clone, Hash, serde::Serialize)]
+    #[derive(Debug, PartialEq, Eq, Clone, Hash, serde::Serialize, TS)]
+    #[ts(export, export_to = "../../../src/bindings/st_gradient_type.ts")]
     StGradientType {
         Linear => "linear",
         Path => "path",
@@ -418,7 +421,8 @@ xml_serde_enum! {
 
 xml_serde_enum! {
     /// 18.18.40
-    #[derive(Debug, PartialEq, Eq, Hash, Clone, serde::Serialize)]
+    #[derive(Debug, PartialEq, Eq, Hash, Clone, serde::Serialize, TS)]
+    #[ts(export, export_to = "../../../src/bindings/st_horizontal_alignment.ts")]
     StHorizontalAlignment {
         General => "general",
         Left => "left",
@@ -600,7 +604,8 @@ xml_serde_enum! {
 
 xml_serde_enum! {
     /// 18.18.55
-    #[derive(Debug, PartialEq, Eq, Clone, Hash, serde::Serialize)]
+    #[derive(Debug, PartialEq, Eq, Clone, Hash, serde::Serialize, TS)]
+    #[ts(export, export_to = "../../../src/bindings/st_pattern_type.ts")]
     StPatternType {
         None => "none",
         Solid => "solid",
@@ -1023,7 +1028,8 @@ xml_serde_enum! {
 
 xml_serde_enum! {
     /// 18.18.85
-    #[derive(Debug, PartialEq, Eq, Clone, Hash, serde::Serialize)]
+    #[derive(Debug, PartialEq, Eq, Clone, Hash, serde::Serialize, TS)]
+    #[ts(export, export_to = "../../../src/bindings/st_underline_values.ts")]
     StUnderlineValues {
         Single => "single",
         Double => "double",
@@ -1045,7 +1051,8 @@ xml_serde_enum! {
 
 xml_serde_enum! {
     /// 18.18.88
-    #[derive(Debug, PartialEq, Eq, Clone, Hash, serde::Serialize)]
+    #[derive(Debug, PartialEq, Eq, Clone, Hash, serde::Serialize, TS)]
+    #[ts(export, export_to = "../../../src/bindings/st_vertical_alignment.ts")]
     StVerticalAlignment {
         Top => "top",
         Center => "center",
@@ -1108,7 +1115,8 @@ pub type StUnsignedIntHex = String;
 
 xml_serde_enum! {
     /// 18.18.92
-    #[derive(Debug, PartialEq, Eq, Hash, Clone, serde::Serialize)]
+    #[derive(Debug, PartialEq, Eq, Hash, Clone, serde::Serialize, TS)]
+    #[ts(export, export_to = "../../../src/bindings/st_vertical_align_run.ts")]
     StVerticalAlignRun {
         Baseline => "baseline",
         Superscript => "superscript",
